# InlineResponse20013Bases

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Base ID, a unique identifier for a base | 
**name** | **str** | Name of the base | 
**permission_level** | **str** | User&#x27;s permission level for the base | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

